/***************************************************************************
                          globals.cpp  -  description
                             -------------------
    begin                : 二 10月 21 2003
    copyright            : (C) 2003 by Sheldon Lee Wen
    email                : leewsb@hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

bool verbose = false;
bool very_verbose = false;
bool global_enable = true;
extern "C" void ac_check_lineak(void) {
}
